@@ -1,6 +1,6 @@
 from toga_iOS.libs import UISlider
 
-from .base import SimpleProbe
+from .base import SimpleProbe, UIControlEventTouchUpInside, UIControlEventValueChanged
 
 
 class SliderProbe(SimpleProbe):
@@ -11,7 +11,12 @@ class SliderProbe(SimpleProbe):
         return (self.native.value - self._min) / (self._max - self._min)
 
     def change(self, position):
-        self.native.value = self._min + round(position * (self._max - self._min))
+        self.native.value = self._min + (position * (self._max - self._min))
+        self.native.sendActionsForControlEvents(UIControlEventValueChanged)
+
+    @property
+    def tick_count(self):
+        raise NotImplementedError()
 
     @property
     def _min(self):
@@ -20,3 +25,6 @@ class SliderProbe(SimpleProbe):
     @property
     def _max(self):
         return self.native.maximumValue
+
+    async def release(self):
+        self.native.sendActionsForControlEvents(UIControlEventTouchUpInside)
